.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`morphology`
=========================
.. automodule:: skimage.morphology

.. currentmodule:: skimage.morphology
.. autosummary::

   skimage.morphology.area_closing
   skimage.morphology.area_opening
   skimage.morphology.ball
   skimage.morphology.binary_closing
   skimage.morphology.binary_dilation
   skimage.morphology.binary_erosion
   skimage.morphology.binary_opening
   skimage.morphology.black_tophat
   skimage.morphology.closing
   skimage.morphology.convex_hull_image
   skimage.morphology.convex_hull_object
   skimage.morphology.cube
   skimage.morphology.diameter_closing
   skimage.morphology.diameter_opening
   skimage.morphology.diamond
   skimage.morphology.dilation
   skimage.morphology.disk
   skimage.morphology.erosion
   skimage.morphology.flood
   skimage.morphology.flood_fill
   skimage.morphology.h_maxima
   skimage.morphology.h_minima
   skimage.morphology.label
   skimage.morphology.local_maxima
   skimage.morphology.local_minima
   skimage.morphology.max_tree
   skimage.morphology.max_tree_local_maxima
   skimage.morphology.medial_axis
   skimage.morphology.octagon
   skimage.morphology.octahedron
   skimage.morphology.opening
   skimage.morphology.reconstruction
   skimage.morphology.rectangle
   skimage.morphology.remove_small_holes
   skimage.morphology.remove_small_objects
   skimage.morphology.skeletonize
   skimage.morphology.skeletonize_3d
   skimage.morphology.square
   skimage.morphology.star
   skimage.morphology.thin
   skimage.morphology.watershed
   skimage.morphology.white_tophat



area_closing
------------

.. autofunction:: skimage.morphology.area_closing


.. include:: skimage.morphology.area_closing.examples

area_opening
------------

.. autofunction:: skimage.morphology.area_opening


.. include:: skimage.morphology.area_opening.examples

ball
----

.. autofunction:: skimage.morphology.ball


.. include:: skimage.morphology.ball.examples

binary_closing
--------------

.. autofunction:: skimage.morphology.binary_closing


.. include:: skimage.morphology.binary_closing.examples

binary_dilation
---------------

.. autofunction:: skimage.morphology.binary_dilation


.. include:: skimage.morphology.binary_dilation.examples

binary_erosion
--------------

.. autofunction:: skimage.morphology.binary_erosion


.. include:: skimage.morphology.binary_erosion.examples

binary_opening
--------------

.. autofunction:: skimage.morphology.binary_opening


.. include:: skimage.morphology.binary_opening.examples

black_tophat
------------

.. autofunction:: skimage.morphology.black_tophat


.. include:: skimage.morphology.black_tophat.examples

closing
-------

.. autofunction:: skimage.morphology.closing


.. include:: skimage.morphology.closing.examples

convex_hull_image
-----------------

.. autofunction:: skimage.morphology.convex_hull_image


.. include:: skimage.morphology.convex_hull_image.examples

convex_hull_object
------------------

.. autofunction:: skimage.morphology.convex_hull_object


.. include:: skimage.morphology.convex_hull_object.examples

cube
----

.. autofunction:: skimage.morphology.cube


.. include:: skimage.morphology.cube.examples

diameter_closing
----------------

.. autofunction:: skimage.morphology.diameter_closing


.. include:: skimage.morphology.diameter_closing.examples

diameter_opening
----------------

.. autofunction:: skimage.morphology.diameter_opening


.. include:: skimage.morphology.diameter_opening.examples

diamond
-------

.. autofunction:: skimage.morphology.diamond


.. include:: skimage.morphology.diamond.examples

dilation
--------

.. autofunction:: skimage.morphology.dilation


.. include:: skimage.morphology.dilation.examples

disk
----

.. autofunction:: skimage.morphology.disk


.. include:: skimage.morphology.disk.examples

erosion
-------

.. autofunction:: skimage.morphology.erosion


.. include:: skimage.morphology.erosion.examples

flood
-----

.. autofunction:: skimage.morphology.flood


.. include:: skimage.morphology.flood.examples

flood_fill
----------

.. autofunction:: skimage.morphology.flood_fill


.. include:: skimage.morphology.flood_fill.examples

h_maxima
--------

.. autofunction:: skimage.morphology.h_maxima


.. include:: skimage.morphology.h_maxima.examples

h_minima
--------

.. autofunction:: skimage.morphology.h_minima


.. include:: skimage.morphology.h_minima.examples

label
-----

.. autofunction:: skimage.morphology.label


.. include:: skimage.morphology.label.examples

local_maxima
------------

.. autofunction:: skimage.morphology.local_maxima


.. include:: skimage.morphology.local_maxima.examples

local_minima
------------

.. autofunction:: skimage.morphology.local_minima


.. include:: skimage.morphology.local_minima.examples

max_tree
--------

.. autofunction:: skimage.morphology.max_tree


.. include:: skimage.morphology.max_tree.examples

max_tree_local_maxima
---------------------

.. autofunction:: skimage.morphology.max_tree_local_maxima


.. include:: skimage.morphology.max_tree_local_maxima.examples

medial_axis
-----------

.. autofunction:: skimage.morphology.medial_axis


.. include:: skimage.morphology.medial_axis.examples

octagon
-------

.. autofunction:: skimage.morphology.octagon


.. include:: skimage.morphology.octagon.examples

octahedron
----------

.. autofunction:: skimage.morphology.octahedron


.. include:: skimage.morphology.octahedron.examples

opening
-------

.. autofunction:: skimage.morphology.opening


.. include:: skimage.morphology.opening.examples

reconstruction
--------------

.. autofunction:: skimage.morphology.reconstruction


.. include:: skimage.morphology.reconstruction.examples

rectangle
---------

.. autofunction:: skimage.morphology.rectangle


.. include:: skimage.morphology.rectangle.examples

remove_small_holes
------------------

.. autofunction:: skimage.morphology.remove_small_holes


.. include:: skimage.morphology.remove_small_holes.examples

remove_small_objects
--------------------

.. autofunction:: skimage.morphology.remove_small_objects


.. include:: skimage.morphology.remove_small_objects.examples

skeletonize
-----------

.. autofunction:: skimage.morphology.skeletonize


.. include:: skimage.morphology.skeletonize.examples

skeletonize_3d
--------------

.. autofunction:: skimage.morphology.skeletonize_3d


.. include:: skimage.morphology.skeletonize_3d.examples

square
------

.. autofunction:: skimage.morphology.square


.. include:: skimage.morphology.square.examples

star
----

.. autofunction:: skimage.morphology.star


.. include:: skimage.morphology.star.examples

thin
----

.. autofunction:: skimage.morphology.thin


.. include:: skimage.morphology.thin.examples

watershed
---------

.. autofunction:: skimage.morphology.watershed


.. include:: skimage.morphology.watershed.examples

white_tophat
------------

.. autofunction:: skimage.morphology.white_tophat


.. include:: skimage.morphology.white_tophat.examples

